

## Omnicloud World

It is a fleet of well-known software libraries and frameworks that was been extended by cloud related methods.

Omnicloud now contains components inherited from [Plotly Dash](https://dash.plotly.com), [Pydantic](https://docs.pydantic.dev/), [Dask](https://dask.org), [Odoo](https://odoo.com) & own platform for seamless moving [Airport](https://omnicloud.world/airport), etc.


## Value

Making software for a cloud requires two vectors business-logic & cloud integration codding.

Omnicloud components already contain cloud integration tools, so it gives developers opportunities to work with business-logic only.
